@@ -1,5 +1,6 @@
 
-#' Download and return a data frame of \acronym{GSOD} weather station data inventories
+#' Download and return a data frame of \acronym{GSOD} weather station data
+#'  inventories
 #'
 #' The \acronym{NCEI} maintains a document,
 #' \url{https://www1.ncdc.noaa.gov/pub/data/noaa/isd-inventory.txt}, which lists
@@ -26,7 +27,9 @@
 #' @export get_inventory
 
 get_inventory <- function() {
+  "STNID" <- isd_history <- NULL #nocov
   load(system.file("extdata", "isd_history.rda", package = "GSODR")) #nocov
+  setkeyv(isd_history, "STNID")
 
   tryCatch({
     curl::curl_download(
@@ -35,8 +38,6 @@ get_inventory <- function() {
       quiet = TRUE
     )
 
-    "STNID" <- NULL #nocov
-
     main_body <-
       fread(
         file.path(tempdir(), "inventory.txt"),
@@ -61,6 +62,7 @@ get_inventory <- function() {
       )
 
     main_body[, STNID := paste(main_body$USAF, main_body$WBAN, sep = "-")]
+    setkeyv(main_body, "STNID")
 
     main_body[, c("USAF", "WBAN") := NULL]
 
@@ -77,15 +79,15 @@ get_inventory <- function() {
                                       header[[year_month]])))
     year_month <- gsub("Through ", "", year_month)
 
+    main_body <- isd_history[main_body, on = "STNID"]
+
     class(main_body) <- c("GSODR.Info", class(main_body))
 
     # add attributes for printing df
     attr(main_body, "GSODR.Inventory") <- c(
-      "   *** FEDERAL CLIMATE COMPLEX INTEGRATED SURFACE DATA INVENTORY ***   \n",
-      "   This inventory provides the number of weather observations by   \n",
-      "   STATION-YEAR-MONTH for beginning of record through",
-      year_month,
-      "   \n"
+      "  *** FEDERAL CLIMATE COMPLEX INTEGRATED SURFACE DATA INVENTORY ***  \n",
+      "  This inventory provides the number of weather observations by  \n",
+      "  STATION-YEAR-MONTH for beginning of record through", year_month, "  \n"
     )
   },
   error = function(cond) {
@@ -97,13 +99,13 @@ get_inventory <- function() {
     )
   })
 
-  return(main_body)
   unlink(file.path(tempdir(), "inventory.txt"))
+  return(main_body)
 }
 
 #' Prints GSODR.info object.
 #'
-#' @param x GSODR.info object
+#' @param x GSODR.Info object
 #' @param ... ignored
 #' @export
 print.GSODR.Info <- function(x, ...) {
